<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.smdesign.rs/kupindo-integracija
 * @since      1.0.0
 *
 * @package    Kupindo_Feed
 * @subpackage Kupindo_Feed/admin/partial
 * @author     Smdesign Studio <podrska@smdesign.rs>
 */
class Kupindo_Feed_Admin
{

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $kupindo_feed The ID of this plugin.
     */
    private $kupindo_feed;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     *
     * @param      string $kupindo_feed The name of this plugin.
     * @param      string $version The version of this plugin.
     */
    public function __construct($kupindo_feed, $version)
    {

        $this->kupindo_feed = $kupindo_feed;
        $this->version = $version;

    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in kupindo_feed_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The kupindo_feed_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_register_style($this->kupindo_feed, plugin_dir_url(__FILE__) . 'css/kupindo-feed-admin.css', array(), $this->version, 'all');
        wp_enqueue_style($this->kupindo_feed);

    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts()
    {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Kupindo_Feed_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The kupindo_feed_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        
        wp_register_script($this->kupindo_feed . "_jvalidate", plugin_dir_url(__FILE__) . 'js/jquery.validate.min.js', array(), $this->version, false);
        wp_enqueue_script($this->kupindo_feed . "_jvalidate");
        wp_register_script($this->kupindo_feed . "_jvalidateadition", plugin_dir_url(__FILE__) . 'js/additional-methods.min.js', array(), $this->version, false);
        wp_enqueue_script($this->kupindo_feed . "_jvalidateadition");

        wp_register_script($this->kupindo_feed . "_shortable", plugin_dir_url(__FILE__) . 'js/jquery-sortable.js', array(), $this->version, false);
        wp_enqueue_script($this->kupindo_feed . "_shortable");

        wp_register_script($this->kupindo_feed, plugin_dir_url(__FILE__) . 'js/kupindo-feed-admin.js', array('jquery'), $this->version, false);

        $wpf_feed_nonce = wp_create_nonce('wpf_feed_nonce');
        wp_localize_script($this->kupindo_feed, 'wpf_ajax_obj', array(
            'wpf_ajax_url' => admin_url('admin-ajax.php'),
            'nonce' => $wpf_feed_nonce,
        ));

        wp_enqueue_script($this->kupindo_feed);

    }

    /**
     * Register the Plugin's Admin Pages for the admin area.
     *
     * @since    1.0.0
     */
    public function load_admin_pages()
    {
        /**
         * This function is provided for making admin pages into admin area.
         *
         * An instance of this class should be passed to the run() function
         * defined in WOO_FEED_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The WOO_FEED_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        if (function_exists('add_options_page')) {

            add_menu_page(__('Kupindo Feed', 'kupindo-feed'), __('Kupindo Feed', 'kupindo-feed'), 'manage_options', __FILE__, 'kupindo_feed_generate_feed', plugin_dir_url(__FILE__) . 'images/kupindo-icon.png');
            add_submenu_page(__FILE__, __('Make Feed', 'kupindo-feed'), __('Make Feed', 'kupindo-feed'), 'manage_options', __FILE__, 'kupindo_feed_generate_feed');
            add_submenu_page(__FILE__, __('Manage Feeds', 'kupindo-feed'), __('Manage Feeds', 'kupindo-feed'), 'manage_options', 'kupindo_feed_manage_feed', 'kupindo_feed_manage_feed');
            add_submenu_page(__FILE__, __('Settings', 'kupindo-feed'), __('Settings', 'kupindo-feed'), 'manage_options', 'kupindo_feed_config_feed', 'kupindo_feed_config_feed');
        }
    }

}
